importFrom("grDevices", "dev.new", "devAskNewPage", "nclass.Sturges")

importFrom("graphics", "Axis", "abline", "axis", "box", "hist",
           "lines", "mtext", "par", "plot", "points", "polygon",
             "rect", "segments", "text", "title", "xinch", "yinch")

importFrom("stats", "anova", "aov", "approx", "ar.yw", "arima",
           "binom.test", "cor", "dbeta", "dchisq", "dhyper", "dlnorm",
           "dnorm", "dpois", "formula", "integrate", "kruskal.test",
           "ks.test", "lm", "mad", "median", "model.frame", "na.pass",
           "nlminb", "optim", "pbeta", "pbinom", "pchisq", "pf", "pgamma",
           "phyper", "plnorm", "pnbinom", "pnorm", "ppoints", "ppois",
           "prop.test", "pt", "qbeta", "qbinom", "qchisq", "qexp",
           "qf", "qgamma", "qgeom", "qhyper", "qlnorm", "qlogis",
           "qnbinom", "qnorm", "qpois", "qt", "quantile", "qunif",
           "qweibull", "rbinom", "rchisq", "residuals", "rlnorm",
           "rnorm", "runif", "sd", "summary.aov", "t.test", "terms",
           "time", "uniroot", "update", "var")

importFrom("utils", "combn", "find", "modifyList")

export(anovaPE,
	aovN,
	aovPower,
	base,
	boxcox,
	boxcoxCensored,
	boxcoxTransform,
	calibrate,
	cdfCompare,
	cdfCompareCensored,
	cdfPlot,
	chenTTest,
	ciBinomHalfWidth,
	ciBinomN,
	ciNormHalfWidth,
	ciNormN,
	ciNparConfLevel,
	ciNparN,
	ciTableMean,
	ciTableProp,
	cv,
	dchi,
	demp,
	detectionLimitCalibrate,
	devd,
        dgammaAlt,
	dgevd,
	distChoose,
	distChooseCensored,
	dlnormAlt,
	dlnormMix,
	dlnormMixAlt,
	dlnormTrunc,
	dlnormTruncAlt,
	dlnorm3,
	dnormMix,
	dnormTrunc,
	dpareto,
	dtri,
	dzmlnorm,
	dzmlnormAlt,
	dzmnorm,
	ebeta,
	ebinom,
	ecdfPlot,
	ecdfPlotCensored,
	eevd,
	eexp,
	egamma,
        egammaAlt,
	egammaCensored,
	egammaAltCensored,
	egeom,
	egevd,
	ehyper,
	elnorm,
	elnormAlt,
	elnormCensored,
	elnormAltCensored,
	elnorm3,
	elogis,
	enbinom,
	enorm,
	enormCensored,
	enparCensored,
	epareto,
	epdfPlot,
	epois,
	epoisCensored,
	eqbeta,
	eqbinom,
	eqevd,
	eqexp,
	eqgamma,
	eqgammaAlt,
	eqgeom,
	eqgevd,
	eqhyper,
	eqlnorm,
	eqlnormCensored,
	eqlnorm3,
	eqlogis,
	eqnbinom,
	eqnorm,
	eqnormCensored,
	eqnpar,
	eqpareto,
	eqpois,
	equnif,
	eqweibull,
	eqzmlnorm,
	eqzmlnormAlt,
	eqzmnorm,
	errorBar,
	eunif,
	evNormOrdStats,
	evNormOrdStatsScalar,
	eweibull,
	ezmlnorm,
	ezmlnormAlt,
	ezmnorm,
	geom_stripchart,
	geoMean,
	geoSD,
        gofTest,
	gofGroupTest,
	gofTestCensored,
	gpqCiNormSinglyCensored,
	gpqCiNormMultiplyCensored,
	gpqTolIntNormSinglyCensored,
	gpqTolIntNormMultiplyCensored,
	inversePredictCalibrate,
	iqr,
	kendallTrendTest,
	kendallSeasonalTrendTest,
	kurtosis,
	lMoment,
	linearTrendTestN,
	linearTrendTestPower,
	linearTrendTestScaledMds,
	longToWide,
	newsEnvStats,
	oneSamplePermutationTest,
	pchi,
	pdfPlot,
	pemp,
	pevd,
        pgammaAlt,
	pgevd,
	plnormAlt,
	plnormMix,
	plnormMixAlt,
	plnormTrunc,
	plnormTruncAlt,
	plnorm3,
	plotAovDesign,
	plotCiBinomDesign,
	plotCiNormDesign,
	plotCiNparDesign,
	plotLinearTrendTestDesign,
	plotPredIntLnormAltSimultaneousTestPowerCurve,
	plotPredIntLnormAltTestPowerCurve,
	plotPredIntNormDesign,
	plotPredIntNormSimultaneousTestPowerCurve,
	plotPredIntNormTestPowerCurve,
	plotPredIntNparDesign,
	plotPredIntNparSimultaneousDesign,
	plotPredIntNparSimultaneousTestPowerCurve,
	plotPropTestDesign,
	plotTTestDesign,
	plotTTestLnormAltDesign,
	plotTolIntNormDesign,
	plotTolIntNparDesign,
	plot.boxcox,
	plot.boxcoxLm,
	plot.boxcoxCensored,
	plot.gof,
	plot.gofCensored,
	plot.gofGroup,
	plot.gofTwoSample,
	plot.permutationTest,
	pnormMix,
	pnormTrunc,
	pointwise,
	ppareto,
	ppointsCensored,
	predict,
	predict.default,
	predict.lm,
	predIntGamma,
	predIntGammaAlt,
	predIntGammaSimultaneous,
	predIntGammaAltSimultaneous,
	predIntLnorm,
        predIntLnormAlt,
	predIntLnormAltSimultaneousTestPower,
	predIntLnormAltTestPower,
	predIntLnormSimultaneous,
        predIntLnormAltSimultaneous,
	predIntNorm,
	predIntNormHalfWidth,
	predIntNormK,
	predIntNormN,
	predIntNormSimultaneous,
	predIntNormSimultaneousK,
	predIntNormSimultaneousTestPower,
	predIntNormTestPower,
	predIntNpar,
	predIntNparConfLevel,
	predIntNparN,
	predIntNparSimultaneous,
	predIntNparSimultaneousConfLevel,
	predIntNparSimultaneousN,
	predIntNparSimultaneousTestPower,
	predIntPois,
	print.boxcox,
	print.boxcoxCensored,
	print.boxcoxLm,
	print.estimate,
	print.estimateCensored,
	print.gof,
	print.gofCensored,
	print.gofGroup,
	print.gofOutlier,
	print,
	print.default,
	print.htest,
	print.htestEnvStats,
	print.htestCensored,
	print.permutationTest,
	print.summaryStats,
	print.gofTwoSample,
	propTestMdd,
	propTestN,
	propTestPower,
	ptri,
	pwMoment,
	pzmlnorm,
	pzmlnormAlt,
	pzmnorm,
	qchi,
	qemp,
	qevd,
        qgammaAlt,
	qgevd,
	qlnormAlt,
	qlnormMix,
	qlnormMixAlt,
	qlnormTrunc,
	qlnormTruncAlt,
	qlnorm3,
	qnormMix,
	qnormTrunc,
	qpareto,
	qqPlot,
	qqPlotCensored,
	qqPlotGestalt,
	qtri,
	quantileTest,
	quantileTestPValue,
	qzmlnorm,
	qzmlnormAlt,
	qzmnorm,
	rchi,
	remp,
	revd,
        rgammaAlt,
	rgevd,
	rlnormAlt,
	rlnormMix,
	rlnormMixAlt,
	rlnormTrunc,
	rlnormTruncAlt,
	rlnorm3,
	rnormMix,
	rnormTrunc,
	rosnerTest,
	rpareto,
	rtri,
	rzmlnorm,
	rzmlnormAlt,
	rzmnorm,
	serialCorrelationTest,
	signTest,
	simulateMvMatrix,
	simulateVector,
	skewness,
	stat_n_text,
	StatNText,
	stat_mean_sd_text,
	StatMeanSDText,
	stat_median_iqr_text,
	StatMedianIQRText,
	stat_test_text,
	StatTestText,
	stripChart,
	summaryFull,
	summaryStats,
	tTestAlpha,
	tTestN,
	tTestPower,
	tTestLnormAltN,
	tTestLnormAltPower,
	tTestLnormAltRatioOfMeans,
	tTestScaledMdd,
	tolIntGamma,
	tolIntGammaAlt,
	tolIntLnorm,
        tolIntLnormAlt,
	tolIntLnormCensored,
	tolIntNorm,
	tolIntNormHalfWidth,
	tolIntNormK,
	tolIntNormN,
	tolIntNormCensored,
	tolIntNpar,
	tolIntNparConfLevel,
	tolIntNparCoverage,
	tolIntNparN,
	tolIntPois,
	twoSampleLinearRankTest,
	twoSampleLinearRankTestCensored,
	twoSamplePermutationTestLocation,
	twoSamplePermutationTestProportion,
	varGroupTest,
	varTest,
	zTestGevdShape,
	enpar)

S3method(boxcox, default)
S3method(boxcox, lm)
S3method(distChoose, default)
S3method(distChoose, formula)
S3method(gofTest, default)
S3method(gofTest, formula)
S3method(gofGroupTest, default)
S3method(gofGroupTest, formula)
S3method(gofGroupTest, data.frame)
S3method(gofGroupTest, matrix)
S3method(gofGroupTest, list)
S3method(kendallSeasonalTrendTest, default)
S3method(kendallSeasonalTrendTest, data.frame)
S3method(kendallSeasonalTrendTest, matrix)
S3method(kendallSeasonalTrendTest, formula)
S3method(kendallTrendTest, default)
S3method(kendallTrendTest, formula)
S3method(plot, boxcox)
S3method(plot, boxcoxLm)
S3method(plot, boxcoxCensored)
S3method(plot, gof)
S3method(plot, gofCensored)
S3method(plot, gofGroup)
S3method(plot, gofTwoSample)
S3method(plot, permutationTest)
S3method(predict, default)
S3method(predict, lm)
S3method(print, default)
S3method(print, boxcox)
S3method(print, boxcoxCensored)
S3method(print, boxcoxLm)
S3method(print, distChoose)
S3method(print, estimate)
S3method(print, estimateCensored)
S3method(print, gof)
S3method(print, gofCensored)
S3method(print, gofGroup)
S3method(print, gofOutlier)
S3method(print, htest)
S3method(print, htestCensored)
S3method(print, permutationTest)
S3method(print, summaryStats)
S3method(print, gofTwoSample)
S3method(print, distChooseCensored)
S3method(print, intervalEstimate)
S3method(print, intervalEstimateCensored)
S3method(print, htestEnvStats)
S3method(serialCorrelationTest, default)
S3method(serialCorrelationTest, lm)
S3method(stripChart, default)
S3method(stripChart, formula)
S3method(summaryFull, default)
S3method(summaryFull, data.frame)
S3method(summaryFull, matrix)
S3method(summaryFull, list)
S3method(summaryFull, formula)
S3method(summaryStats, default)
S3method(summaryStats, factor)
S3method(summaryStats, data.frame)
S3method(summaryStats, matrix)
S3method(summaryStats, list)
S3method(summaryStats, formula)
S3method(summaryStats, logical)
S3method(summaryStats, character)
S3method(varGroupTest, default)
S3method(varGroupTest, data.frame)
S3method(varGroupTest, matrix)
S3method(varGroupTest, list)
S3method(varGroupTest, formula)
